@@ -9,17 +9,19 @@ BEGIN { die 'Perl version 5.6.0 or greater is required' if ($] < 5.006); }
 
 =head1 NAME
 
-Net::SNTP::Client - Perl module to retrieve higher fraction accuracy from NTP server
+Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
+ system clock offset t from NTP or SNTP Server.
+
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
     $VERSION = eval $VERSION;
 
 ## Load our modules
@@ -36,16 +38,11 @@ our @EXPORT      = qw ( getSNTPTime );
 
 =head1 SYNOPSIS
 
-  use Net::SNTP::Client;
+The Net::SNTP::Client - Perl module retrieves the time from an NTP server
+ and uses the local time to calculate the roundtrip delay d and system 
+ clock offset t based on RFC4330. The module is calculating with higher
+ accuracy in comparison to other modules.
 
-  my %hashInput = (
-      -hostname      => "0.pool.ntp.org", # hostnmae or IP
-      -port          => 123, # default NTP port 123 
-      -RFC4330       => 1,
-      -clearScreen   => 1,
-      );
-
-  my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
 
 =head1 ABSTRACT
 
@@ -55,6 +52,7 @@ The module sends a UDP packet formated according to
  human readable form and also calculated the roundtrip delay d
  and system clock offset t, based on the decoded data.
 
+
 =head1 DESCRIPTION
 
 This module exports a single method (getSNTPTime) and returns
@@ -68,10 +66,10 @@ This module exports a single method (getSNTPTime) and returns
 =head2 EXPORT
 
   my %hashInput = (
-      -hostname      => "0.pool.ntp.org", # hostnmae or IP
-      -port          => 123, # default NTP port 123 
-      -RFC4330       => 1,
-      -clearScreen   => 1,
+      -hostname      => $hostname,    # hostnmae or IP
+      -port          => $port,        # default NTP port 123 
+      -RFC4330       => $RFC4330,     # default 0
+      -clearScreen   => $clearScreen, # default 0
       );
 
   my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
@@ -79,21 +77,37 @@ This module exports a single method (getSNTPTime) and returns
 This module exports a single method - getSNTPTime and an error
  string in case of an error or a faulty operation. It expects a
  hash as an input. The input can have four different hash
- keys => values (-hostname, port, RFC4330 and -clearScreen). 
+ keys (-hostname, port, RFC4330 and -clearScreen). 
 
--hostname: The mandatory key inorder the method to produce
- an output is only the hostname, the rest of the keys are optional. 
+=item HOSTNAME
 
--port: By default the the port is set to 123 (NTP default port). 
- The user has the option to overwite the port based on the expected
-NTP port on the server side (e.g. -port => 123456).
+    -hostname: The mandatory key inorder the method to produce
+    an output is only the hostname, the rest of the keys are optional. 
 
--RFC4330: This is an optional way to produce an easy visuable
- output based on RFC4330 documentation.
+=over
 
--clearScreen: This is an optional choice based on user preference
- if he/she desires to clear the "terminal screen" before printing
- the captured data.
+=item PORT
+
+    -port: By default the the port is set to 123 (NTP default port). 
+    The user has the option to overwite the port based on the expected
+    NTP port on the server side (e.g. -port => 123456).
+
+=over
+
+=item RFC4330 OUTPUT
+
+    -RFC4330: This is an optional way to produce an easy visuable
+    output based on RFC4330 documentation.
+
+=over
+
+=item CLEARSCREEN
+
+    -clearScreen: This is an optional choice based on user preference
+    if he/she desires to clear the "terminal screen" before printing
+    the captured data.
+
+=over
 
 =head1 SUBROUTINES/METHODS
 
@@ -366,6 +380,36 @@ sub getSNTPTime {
     return $error, \%moduleOutput;
 }
 
+=head1 EXAMPLE
+
+This example gets the time from a remote NTP server from the
+ L<pool.ntp.org: public ntp time server for everyone|http://www.pool.ntp.org/en/> 
+ and calculates the roundtrip delay d and local clock offset
+ t as defined on RFC4330.
+
+We use the L<Data::Dumper|http://search.cpan.org/~ilyam/Data-Dumper-2.121/Dumper.pm>
+ module to print the output.
+
+#!/usr/bin/perl
+use strict;
+use warnings;
+use Data::Dumper;
+
+use Net::SNTP::Client;
+
+my %hashInput = (
+    -hostname      => "0.pool.ntp.org",
+    -port          => 123,
+    -RFC4330       => 1,
+    -clearScreen   => 1,
+    );
+
+my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
+
+print Dumper $hashRefOutput;
+print "Error: $error\n" if ($error);
+
+
 =head1 AUTHOR
 
 Athanasios Garyfalos, C<< <garyfalos at cpan.org> >>
